from distutils.core import setup #如果没有需要先安装  
setup(name='edenpyhaha',  #打包后的包文件名   
      version='1.0.1',  #版本  
      description='description',     
      author=' ',     
      author_email=' ',     
      url=' ',     
      py_modules=['edenpy'],  #与前面的新建文件名一致   
)